@@ -34,7 +34,7 @@ sub NAME {
 		return $name;
 	}
 	else {
-		error("ınvalid build system class name: $class");
+		error("Invalid build system class name: $class");
 	}
 }
 
@@ -122,11 +122,18 @@ sub new {
 
 	if (defined($target_bs_name)) {
 		my %target_opts = %opts;
+		# Let the target know it is used as a target build system.
+		# E.g. the makefile has special cases based on whether it is
+		# the main or a target build system.
 		delete($target_opts{'targetbuildsystem'});
+		$target_opts{'_is_targetbuildsystem'} = 1;
 		my $target_system =_create_buildsystem_instance($target_bs_name, 1, %target_opts);
 		$this->set_targetbuildsystem($target_system);
 	}
 
+	$this->{'_is_targetbuildsystem'} = $opts{'_is_targetbuildsystem'}
+	  if exists($opts{'_is_targetbuildsystem'});
+
 	if (exists $opts{sourcedir}) {
 		# Get relative sourcedir abs_path (without symlinks)
 		my $abspath = Cwd::abs_path($opts{sourcedir});
@@ -199,6 +206,12 @@ sub set_targetbuildsystem {
 	$this->{'targetbuildsystem'} = $target_system
 }
 
+sub _is_targetbuildsystem {
+	my ($this) = @_;
+	return 0 if not exists($this->{'_is_targetbuildsystem'});
+	return $this->{'_is_targetbuildsystem'};
+}
+
 # Returns the target build system if it is provided
 sub get_targetbuildsystem {
 	my $this = shift;
@@ -218,12 +231,12 @@ sub get_targetbuildsystem {
 # be buildable or not. However, if the build system is derived from
 # another other auto-buildable build system, this method
 # may also check if the source has already been built with this build
-# system partitially by looking for temporary files or other common
+# system partially by looking for temporary files or other common
 # results the build system produces during the build process. The
 # latter checks must be unique to the current build system and must
 # be very unlikely to be true for either its parent or other build
 # systems. If it is determined that the source has already built
-# partitially with this build system, the value returned must be
+# partially with this build system, the value returned must be
 # greater than the one of the SUPER call.
 sub check_auto_buildable {
 	my $this=shift;
@@ -415,30 +428,6 @@ sub check_auto_buildable_clean_oos_buildir {
 	return 1;
 }
 
-sub _cd {
-	my ($this, $dir)=@_;
-	verbose_print("cd $dir");
-	if (! $dh{NO_ACT}) {
-		chdir $dir or error("error: unable to chdir to $dir");
-	}
-}
-
-sub _in_dir {
-	my ($this, $dir, $code, @args) = @_;
-	if ($dir ne '.') {
-		my $ret;
-		$this->_cd($dir);
-		eval {
-			$ret = $code->(@args);
-		};
-		my $saved_exception = $@;
-		$this->_cd($this->_rel2rel($this->{cwd}, $dir));
-		die $saved_exception if $saved_exception;
-		return $ret;
-	}
-	return $code->(@args);
-}
-
 sub _generic_doit_in_dir {
 	my ($this, $dir, $sub, @args) = @_;
 	my %args;
